# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Choice(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'emarket': 'bool',
        'emarket_id': 'str',
        'ovz': 'bool',
        'vzmr': 'bool',
        'minister_exception': 'bool'
    }

    attribute_map = {
        'emarket': 'emarket',
        'emarket_id': 'emarket_id',
        'ovz': 'ovz',
        'vzmr': 'vzmr',
        'minister_exception': 'minister_exception'
    }

    def __init__(self, emarket=None, emarket_id=None, ovz=None, vzmr=None, minister_exception=None):  # noqa: E501
        """Choice - a model defined in Swagger"""  # noqa: E501
        self._emarket = None
        self._emarket_id = None
        self._ovz = None
        self._vzmr = None
        self._minister_exception = None
        self.discriminator = None
        if emarket is not None:
            self.emarket = emarket
        if emarket_id is not None:
            self.emarket_id = emarket_id
        if ovz is not None:
            self.ovz = ovz
        if vzmr is not None:
            self.vzmr = vzmr
        if minister_exception is not None:
            self.minister_exception = minister_exception

    @property
    def emarket(self):
        """Gets the emarket of this Choice.  # noqa: E501

        choice_company_emarket - Elektronické tržiště (ET)  # noqa: E501

        :return: The emarket of this Choice.  # noqa: E501
        :rtype: bool
        """
        return self._emarket

    @emarket.setter
    def emarket(self, emarket):
        """Sets the emarket of this Choice.

        choice_company_emarket - Elektronické tržiště (ET)  # noqa: E501

        :param emarket: The emarket of this Choice.  # noqa: E501
        :type: bool
        """

        self._emarket = emarket

    @property
    def emarket_id(self):
        """Gets the emarket_id of this Choice.  # noqa: E501

        choice_company_emarket_id - Identifikátor záznamu v ET  # noqa: E501

        :return: The emarket_id of this Choice.  # noqa: E501
        :rtype: str
        """
        return self._emarket_id

    @emarket_id.setter
    def emarket_id(self, emarket_id):
        """Sets the emarket_id of this Choice.

        choice_company_emarket_id - Identifikátor záznamu v ET  # noqa: E501

        :param emarket_id: The emarket_id of this Choice.  # noqa: E501
        :type: str
        """

        self._emarket_id = emarket_id

    @property
    def ovz(self):
        """Gets the ovz of this Choice.  # noqa: E501

        choice_company_ovz - Prostřednictvím OVZ  # noqa: E501

        :return: The ovz of this Choice.  # noqa: E501
        :rtype: bool
        """
        return self._ovz

    @ovz.setter
    def ovz(self, ovz):
        """Sets the ovz of this Choice.

        choice_company_ovz - Prostřednictvím OVZ  # noqa: E501

        :param ovz: The ovz of this Choice.  # noqa: E501
        :type: bool
        """

        self._ovz = ovz

    @property
    def vzmr(self):
        """Gets the vzmr of this Choice.  # noqa: E501

        choice_vzmr - VZMR II. kategorie: Protokol o výběru nejvýhodnější nabídky  # noqa: E501

        :return: The vzmr of this Choice.  # noqa: E501
        :rtype: bool
        """
        return self._vzmr

    @vzmr.setter
    def vzmr(self, vzmr):
        """Sets the vzmr of this Choice.

        choice_vzmr - VZMR II. kategorie: Protokol o výběru nejvýhodnější nabídky  # noqa: E501

        :param vzmr: The vzmr of this Choice.  # noqa: E501
        :type: bool
        """

        self._vzmr = vzmr

    @property
    def minister_exception(self):
        """Gets the minister_exception of this Choice.  # noqa: E501

        choice_minister_exception - Výjimka ministra   # noqa: E501

        :return: The minister_exception of this Choice.  # noqa: E501
        :rtype: bool
        """
        return self._minister_exception

    @minister_exception.setter
    def minister_exception(self, minister_exception):
        """Sets the minister_exception of this Choice.

        choice_minister_exception - Výjimka ministra   # noqa: E501

        :param minister_exception: The minister_exception of this Choice.  # noqa: E501
        :type: bool
        """

        self._minister_exception = minister_exception

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Choice, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Choice):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import esmlouvy_connector
from esmlouvy_connector.api.admins_api import AdminsApi  # noqa: E501
from esmlouvy_connector.rest import ApiException


class TestAdminsApi(unittest.TestCase):
    """AdminsApi unit test stubs"""

    def setUp(self):
        self.api = AdminsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_config(self):
        """Test case for get_config

        získá konfiguraci konektoru  # noqa: E501
        """
        pass

    def test_get_profile(self):
        """Test case for get_profile

        získá konfiguraci databáze serveru Domino  # noqa: E501
        """
        pass

    def test_get_profile_dir(self):
        """Test case for get_profile_dir

        získá pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_get_profile_roles(self):
        """Test case for get_profile_roles

        získá pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_put_config(self):
        """Test case for put_config

        aktualizuje hlavní konfiguraci konektoru  # noqa: E501
        """
        pass

    def test_put_profile(self):
        """Test case for put_profile

        aktualizuje nebo vytvoří hlavní konfiguraci aplikace Domino  # noqa: E501
        """
        pass

    def test_put_profile_dir(self):
        """Test case for put_profile_dir

        aktualizuje nebo vytvoří pomocný profil (řízené slovníky) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_put_profile_roles(self):
        """Test case for put_profile_roles

        aktualizuje nebo vytvoří pomocný profil (role) konfigurace databáze serveru Domino  # noqa: E501
        """
        pass

    def test_replace_name(self):
        """Test case for replace_name

        Zamění jméno ve všech dokumentech a polích, kde se vyskytuje  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentAcl(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'system_authors': 'list[str]',
        'system_readers': 'list[str]',
        'or_readers': 'list[str]',
        'ou_readers': 'list[str]',
        'ou_dep_authors': 'list[str]',
        'ou_dep_readers': 'list[str]',
        'responsible_authors': 'list[str]',
        'deputy_creator_name': 'str',
        'general_authors': 'list[str]',
        'unauthorized_readers': 'list[str]',
        'ou_names': 'list[str]',
        'operation_commander_names': 'list[str]',
        'operation_commander_assistant_names': 'list[str]',
        'or_names': 'list[str]',
        'budgeter_names': 'list[str]',
        'assistant_budgeter_names': 'list[str]',
        'ovz_manager_authors': 'list[str]',
        'or_ph_readers': 'list[str]',
        'ovz_names': 'list[str]',
        'consultant_author': 'str'
    }

    attribute_map = {
        'system_authors': 'system_authors',
        'system_readers': 'system_readers',
        'or_readers': 'or_readers',
        'ou_readers': 'ou_readers',
        'ou_dep_authors': 'ou_dep_authors',
        'ou_dep_readers': 'ou_dep_readers',
        'responsible_authors': 'responsible_authors',
        'deputy_creator_name': 'deputy_creator_name',
        'general_authors': 'general_authors',
        'unauthorized_readers': 'unauthorized_readers',
        'ou_names': 'ou_names',
        'operation_commander_names': 'operation_commander_names',
        'operation_commander_assistant_names': 'operation_commander_assistant_names',
        'or_names': 'or_names',
        'budgeter_names': 'budgeter_names',
        'assistant_budgeter_names': 'assistant_budgeter_names',
        'ovz_manager_authors': 'ovz_manager_authors',
        'or_ph_readers': 'or_ph_readers',
        'ovz_names': 'ovz_names',
        'consultant_author': 'consultant_author'
    }

    def __init__(self, system_authors=None, system_readers=None, or_readers=None, ou_readers=None, ou_dep_authors=None, ou_dep_readers=None, responsible_authors=None, deputy_creator_name=None, general_authors=None, unauthorized_readers=None, ou_names=None, operation_commander_names=None, operation_commander_assistant_names=None, or_names=None, budgeter_names=None, assistant_budgeter_names=None, ovz_manager_authors=None, or_ph_readers=None, ovz_names=None, consultant_author=None):  # noqa: E501
        """DocumentAcl - a model defined in Swagger"""  # noqa: E501
        self._system_authors = None
        self._system_readers = None
        self._or_readers = None
        self._ou_readers = None
        self._ou_dep_authors = None
        self._ou_dep_readers = None
        self._responsible_authors = None
        self._deputy_creator_name = None
        self._general_authors = None
        self._unauthorized_readers = None
        self._ou_names = None
        self._operation_commander_names = None
        self._operation_commander_assistant_names = None
        self._or_names = None
        self._budgeter_names = None
        self._assistant_budgeter_names = None
        self._ovz_manager_authors = None
        self._or_ph_readers = None
        self._ovz_names = None
        self._consultant_author = None
        self.discriminator = None
        if system_authors is not None:
            self.system_authors = system_authors
        if system_readers is not None:
            self.system_readers = system_readers
        if or_readers is not None:
            self.or_readers = or_readers
        if ou_readers is not None:
            self.ou_readers = ou_readers
        if ou_dep_authors is not None:
            self.ou_dep_authors = ou_dep_authors
        if ou_dep_readers is not None:
            self.ou_dep_readers = ou_dep_readers
        if responsible_authors is not None:
            self.responsible_authors = responsible_authors
        if deputy_creator_name is not None:
            self.deputy_creator_name = deputy_creator_name
        if general_authors is not None:
            self.general_authors = general_authors
        if unauthorized_readers is not None:
            self.unauthorized_readers = unauthorized_readers
        if ou_names is not None:
            self.ou_names = ou_names
        if operation_commander_names is not None:
            self.operation_commander_names = operation_commander_names
        if operation_commander_assistant_names is not None:
            self.operation_commander_assistant_names = operation_commander_assistant_names
        if or_names is not None:
            self.or_names = or_names
        if budgeter_names is not None:
            self.budgeter_names = budgeter_names
        if assistant_budgeter_names is not None:
            self.assistant_budgeter_names = assistant_budgeter_names
        if ovz_manager_authors is not None:
            self.ovz_manager_authors = ovz_manager_authors
        if or_ph_readers is not None:
            self.or_ph_readers = or_ph_readers
        if ovz_names is not None:
            self.ovz_names = ovz_names
        if consultant_author is not None:
            self.consultant_author = consultant_author

    @property
    def system_authors(self):
        """Gets the system_authors of this DocumentAcl.  # noqa: E501

        SystemAuthors  - seznam osob oprávněných VŽDY zasahovat do spisu  # noqa: E501

        :return: The system_authors of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._system_authors

    @system_authors.setter
    def system_authors(self, system_authors):
        """Sets the system_authors of this DocumentAcl.

        SystemAuthors  - seznam osob oprávněných VŽDY zasahovat do spisu  # noqa: E501

        :param system_authors: The system_authors of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._system_authors = system_authors

    @property
    def system_readers(self):
        """Gets the system_readers of this DocumentAcl.  # noqa: E501

        SystemReaders  # noqa: E501

        :return: The system_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._system_readers

    @system_readers.setter
    def system_readers(self, system_readers):
        """Sets the system_readers of this DocumentAcl.

        SystemReaders  # noqa: E501

        :param system_readers: The system_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._system_readers = system_readers

    @property
    def or_readers(self):
        """Gets the or_readers of this DocumentAcl.  # noqa: E501

        OR_Readers  # noqa: E501

        :return: The or_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._or_readers

    @or_readers.setter
    def or_readers(self, or_readers):
        """Sets the or_readers of this DocumentAcl.

        OR_Readers  # noqa: E501

        :param or_readers: The or_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._or_readers = or_readers

    @property
    def ou_readers(self):
        """Gets the ou_readers of this DocumentAcl.  # noqa: E501

        OU_Readers  # noqa: E501

        :return: The ou_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ou_readers

    @ou_readers.setter
    def ou_readers(self, ou_readers):
        """Sets the ou_readers of this DocumentAcl.

        OU_Readers  # noqa: E501

        :param ou_readers: The ou_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ou_readers = ou_readers

    @property
    def ou_dep_authors(self):
        """Gets the ou_dep_authors of this DocumentAcl.  # noqa: E501

        OU_dep_Authors  # noqa: E501

        :return: The ou_dep_authors of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ou_dep_authors

    @ou_dep_authors.setter
    def ou_dep_authors(self, ou_dep_authors):
        """Sets the ou_dep_authors of this DocumentAcl.

        OU_dep_Authors  # noqa: E501

        :param ou_dep_authors: The ou_dep_authors of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ou_dep_authors = ou_dep_authors

    @property
    def ou_dep_readers(self):
        """Gets the ou_dep_readers of this DocumentAcl.  # noqa: E501

        OU_dep_Readers  # noqa: E501

        :return: The ou_dep_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ou_dep_readers

    @ou_dep_readers.setter
    def ou_dep_readers(self, ou_dep_readers):
        """Sets the ou_dep_readers of this DocumentAcl.

        OU_dep_Readers  # noqa: E501

        :param ou_dep_readers: The ou_dep_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ou_dep_readers = ou_dep_readers

    @property
    def responsible_authors(self):
        """Gets the responsible_authors of this DocumentAcl.  # noqa: E501

        responsible_Authors  # noqa: E501

        :return: The responsible_authors of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._responsible_authors

    @responsible_authors.setter
    def responsible_authors(self, responsible_authors):
        """Sets the responsible_authors of this DocumentAcl.

        responsible_Authors  # noqa: E501

        :param responsible_authors: The responsible_authors of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._responsible_authors = responsible_authors

    @property
    def deputy_creator_name(self):
        """Gets the deputy_creator_name of this DocumentAcl.  # noqa: E501

        deputy_creator  # noqa: E501

        :return: The deputy_creator_name of this DocumentAcl.  # noqa: E501
        :rtype: str
        """
        return self._deputy_creator_name

    @deputy_creator_name.setter
    def deputy_creator_name(self, deputy_creator_name):
        """Sets the deputy_creator_name of this DocumentAcl.

        deputy_creator  # noqa: E501

        :param deputy_creator_name: The deputy_creator_name of this DocumentAcl.  # noqa: E501
        :type: str
        """

        self._deputy_creator_name = deputy_creator_name

    @property
    def general_authors(self):
        """Gets the general_authors of this DocumentAcl.  # noqa: E501

        Autori  -  seznam osob oprávněných upravovat záznam, mění se podle stavu (jednotlivé útvary resp. lidé v nich by tedy měly mít v ACL Author)|   # noqa: E501

        :return: The general_authors of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._general_authors

    @general_authors.setter
    def general_authors(self, general_authors):
        """Sets the general_authors of this DocumentAcl.

        Autori  -  seznam osob oprávněných upravovat záznam, mění se podle stavu (jednotlivé útvary resp. lidé v nich by tedy měly mít v ACL Author)|   # noqa: E501

        :param general_authors: The general_authors of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._general_authors = general_authors

    @property
    def unauthorized_readers(self):
        """Gets the unauthorized_readers of this DocumentAcl.  # noqa: E501

        Viditelne_Neauth  Readers pro neautorizovane polozky  # noqa: E501

        :return: The unauthorized_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._unauthorized_readers

    @unauthorized_readers.setter
    def unauthorized_readers(self, unauthorized_readers):
        """Sets the unauthorized_readers of this DocumentAcl.

        Viditelne_Neauth  Readers pro neautorizovane polozky  # noqa: E501

        :param unauthorized_readers: The unauthorized_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._unauthorized_readers = unauthorized_readers

    @property
    def ou_names(self):
        """Gets the ou_names of this DocumentAcl.  # noqa: E501

        ou -  (jména)  odborný útvar  # noqa: E501

        :return: The ou_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ou_names

    @ou_names.setter
    def ou_names(self, ou_names):
        """Sets the ou_names of this DocumentAcl.

        ou -  (jména)  odborný útvar  # noqa: E501

        :param ou_names: The ou_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ou_names = ou_names

    @property
    def operation_commander_names(self):
        """Gets the operation_commander_names of this DocumentAcl.  # noqa: E501

        prikazce -  (jména)    příkazce operace  # noqa: E501

        :return: The operation_commander_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._operation_commander_names

    @operation_commander_names.setter
    def operation_commander_names(self, operation_commander_names):
        """Sets the operation_commander_names of this DocumentAcl.

        prikazce -  (jména)    příkazce operace  # noqa: E501

        :param operation_commander_names: The operation_commander_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._operation_commander_names = operation_commander_names

    @property
    def operation_commander_assistant_names(self):
        """Gets the operation_commander_assistant_names of this DocumentAcl.  # noqa: E501

        asistent_prikazce (jmena) - asistent příkazce operace   # noqa: E501

        :return: The operation_commander_assistant_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._operation_commander_assistant_names

    @operation_commander_assistant_names.setter
    def operation_commander_assistant_names(self, operation_commander_assistant_names):
        """Sets the operation_commander_assistant_names of this DocumentAcl.

        asistent_prikazce (jmena) - asistent příkazce operace   # noqa: E501

        :param operation_commander_assistant_names: The operation_commander_assistant_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._operation_commander_assistant_names = operation_commander_assistant_names

    @property
    def or_names(self):
        """Gets the or_names of this DocumentAcl.  # noqa: E501

        or -  (jména)  odbor rozpočtu  # noqa: E501

        :return: The or_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._or_names

    @or_names.setter
    def or_names(self, or_names):
        """Sets the or_names of this DocumentAcl.

        or -  (jména)  odbor rozpočtu  # noqa: E501

        :param or_names: The or_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._or_names = or_names

    @property
    def budgeter_names(self):
        """Gets the budgeter_names of this DocumentAcl.  # noqa: E501

        orr -  (jména)  odbor rozpočtu - rozpočtář  # noqa: E501

        :return: The budgeter_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._budgeter_names

    @budgeter_names.setter
    def budgeter_names(self, budgeter_names):
        """Sets the budgeter_names of this DocumentAcl.

        orr -  (jména)  odbor rozpočtu - rozpočtář  # noqa: E501

        :param budgeter_names: The budgeter_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._budgeter_names = budgeter_names

    @property
    def assistant_budgeter_names(self):
        """Gets the assistant_budgeter_names of this DocumentAcl.  # noqa: E501

        orr_help -  (jména)  odbor rozpočtu - pomocný rozpočtář  # noqa: E501

        :return: The assistant_budgeter_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._assistant_budgeter_names

    @assistant_budgeter_names.setter
    def assistant_budgeter_names(self, assistant_budgeter_names):
        """Sets the assistant_budgeter_names of this DocumentAcl.

        orr_help -  (jména)  odbor rozpočtu - pomocný rozpočtář  # noqa: E501

        :param assistant_budgeter_names: The assistant_budgeter_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._assistant_budgeter_names = assistant_budgeter_names

    @property
    def ovz_manager_authors(self):
        """Gets the ovz_manager_authors of this DocumentAcl.  # noqa: E501

        ovz_manager - OVZ- Manager  # noqa: E501

        :return: The ovz_manager_authors of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ovz_manager_authors

    @ovz_manager_authors.setter
    def ovz_manager_authors(self, ovz_manager_authors):
        """Sets the ovz_manager_authors of this DocumentAcl.

        ovz_manager - OVZ- Manager  # noqa: E501

        :param ovz_manager_authors: The ovz_manager_authors of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ovz_manager_authors = ovz_manager_authors

    @property
    def or_ph_readers(self):
        """Gets the or_ph_readers of this DocumentAcl.  # noqa: E501

        or_ph - OVZ - právník  # noqa: E501

        :return: The or_ph_readers of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._or_ph_readers

    @or_ph_readers.setter
    def or_ph_readers(self, or_ph_readers):
        """Sets the or_ph_readers of this DocumentAcl.

        or_ph - OVZ - právník  # noqa: E501

        :param or_ph_readers: The or_ph_readers of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._or_ph_readers = or_ph_readers

    @property
    def ovz_names(self):
        """Gets the ovz_names of this DocumentAcl.  # noqa: E501

        ovz -  (jména)  odbor veřejných zakázek:  - vybere se v akci Zaslat Odboru veřejných zakázek   # noqa: E501

        :return: The ovz_names of this DocumentAcl.  # noqa: E501
        :rtype: list[str]
        """
        return self._ovz_names

    @ovz_names.setter
    def ovz_names(self, ovz_names):
        """Sets the ovz_names of this DocumentAcl.

        ovz -  (jména)  odbor veřejných zakázek:  - vybere se v akci Zaslat Odboru veřejných zakázek   # noqa: E501

        :param ovz_names: The ovz_names of this DocumentAcl.  # noqa: E501
        :type: list[str]
        """

        self._ovz_names = ovz_names

    @property
    def consultant_author(self):
        """Gets the consultant_author of this DocumentAcl.  # noqa: E501

        consultant -  (authors)  poradce NM-ŘSFL  # noqa: E501

        :return: The consultant_author of this DocumentAcl.  # noqa: E501
        :rtype: str
        """
        return self._consultant_author

    @consultant_author.setter
    def consultant_author(self, consultant_author):
        """Sets the consultant_author of this DocumentAcl.

        consultant -  (authors)  poradce NM-ŘSFL  # noqa: E501

        :param consultant_author: The consultant_author of this DocumentAcl.  # noqa: E501
        :type: str
        """

        self._consultant_author = consultant_author

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentAcl, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentAcl):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class BudgetCategory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'department': 'str',
        'category': 'str',
        'category_parsed': 'str',
        'description': 'str'
    }

    attribute_map = {
        'domino': 'domino',
        'department': 'department',
        'category': 'category',
        'category_parsed': 'category_parsed',
        'description': 'description'
    }

    def __init__(self, domino=None, department=None, category=None, category_parsed=None, description=None):  # noqa: E501
        """BudgetCategory - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._department = None
        self._category = None
        self._category_parsed = None
        self._description = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if department is not None:
            self.department = department
        if category is not None:
            self.category = category
        if category_parsed is not None:
            self.category_parsed = category_parsed
        if description is not None:
            self.description = description

    @property
    def domino(self):
        """Gets the domino of this BudgetCategory.  # noqa: E501


        :return: The domino of this BudgetCategory.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this BudgetCategory.


        :param domino: The domino of this BudgetCategory.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def department(self):
        """Gets the department of this BudgetCategory.  # noqa: E501

        odbor  # noqa: E501

        :return: The department of this BudgetCategory.  # noqa: E501
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """Sets the department of this BudgetCategory.

        odbor  # noqa: E501

        :param department: The department of this BudgetCategory.  # noqa: E501
        :type: str
        """

        self._department = department

    @property
    def category(self):
        """Gets the category of this BudgetCategory.  # noqa: E501

        rozpočtové zařazení (bez pomlček)  # noqa: E501

        :return: The category of this BudgetCategory.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this BudgetCategory.

        rozpočtové zařazení (bez pomlček)  # noqa: E501

        :param category: The category of this BudgetCategory.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def category_parsed(self):
        """Gets the category_parsed of this BudgetCategory.  # noqa: E501

        ParsedCategory - rozpočtové zařazení (s pomlčkami)  # noqa: E501

        :return: The category_parsed of this BudgetCategory.  # noqa: E501
        :rtype: str
        """
        return self._category_parsed

    @category_parsed.setter
    def category_parsed(self, category_parsed):
        """Sets the category_parsed of this BudgetCategory.

        ParsedCategory - rozpočtové zařazení (s pomlčkami)  # noqa: E501

        :param category_parsed: The category_parsed of this BudgetCategory.  # noqa: E501
        :type: str
        """

        self._category_parsed = category_parsed

    @property
    def description(self):
        """Gets the description of this BudgetCategory.  # noqa: E501

        popis  # noqa: E501

        :return: The description of this BudgetCategory.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this BudgetCategory.

        popis  # noqa: E501

        :param description: The description of this BudgetCategory.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BudgetCategory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BudgetCategory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Datový konektor Domino pro eSMLOUVY

    Toto je datový konektor umožňující datovou výměnu mezi obchodní logikou aplikace eSMLOUVY a datovým serverem HCL Domino.  Ovládá se pomocí REST API   # noqa: E501

    OpenAPI spec version: 1.1.0
    Contact: info@sysnet.cz
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ProfileRoles(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'domino': 'DominoCommons',
        'prof_tab': 'str',
        'nm_0': 'list[str]',
        'nm_1': 'list[str]',
        'nm_2': 'list[str]',
        'nm_3': 'list[str]',
        'nm_4': 'list[str]',
        'nm_5': 'list[str]',
        'nm_6': 'list[str]',
        'nm_7': 'list[str]',
        'nm_8': 'list[str]',
        'nm_9': 'list[str]',
        'deputy_minister_finance': 'str',
        'budget_department_head': 'str',
        'budget_department_manager': 'list[str]',
        'budget_department_persons': 'list[str]',
        'budget_department_layeman': 'list[str]',
        'budget_department_layeman_ph': 'list[str]',
        'budget_department_surveyors': 'list[str]',
        'sek210': 'str',
        'sek240': 'str'
    }

    attribute_map = {
        'domino': 'domino',
        'prof_tab': 'prof_tab',
        'nm_0': 'nm_0',
        'nm_1': 'nm_1',
        'nm_2': 'nm_2',
        'nm_3': 'nm_3',
        'nm_4': 'nm_4',
        'nm_5': 'nm_5',
        'nm_6': 'nm_6',
        'nm_7': 'nm_7',
        'nm_8': 'nm_8',
        'nm_9': 'nm_9',
        'deputy_minister_finance': 'deputy_minister_finance',
        'budget_department_head': 'budget_department_head',
        'budget_department_manager': 'budget_department_manager',
        'budget_department_persons': 'budget_department_persons',
        'budget_department_layeman': 'budget_department_layeman',
        'budget_department_layeman_ph': 'budget_department_layeman_ph',
        'budget_department_surveyors': 'budget_department_surveyors',
        'sek210': 'sek210',
        'sek240': 'sek240'
    }

    def __init__(self, domino=None, prof_tab=None, nm_0=None, nm_1=None, nm_2=None, nm_3=None, nm_4=None, nm_5=None, nm_6=None, nm_7=None, nm_8=None, nm_9=None, deputy_minister_finance=None, budget_department_head=None, budget_department_manager=None, budget_department_persons=None, budget_department_layeman=None, budget_department_layeman_ph=None, budget_department_surveyors=None, sek210=None, sek240=None):  # noqa: E501
        """ProfileRoles - a model defined in Swagger"""  # noqa: E501
        self._domino = None
        self._prof_tab = None
        self._nm_0 = None
        self._nm_1 = None
        self._nm_2 = None
        self._nm_3 = None
        self._nm_4 = None
        self._nm_5 = None
        self._nm_6 = None
        self._nm_7 = None
        self._nm_8 = None
        self._nm_9 = None
        self._deputy_minister_finance = None
        self._budget_department_head = None
        self._budget_department_manager = None
        self._budget_department_persons = None
        self._budget_department_layeman = None
        self._budget_department_layeman_ph = None
        self._budget_department_surveyors = None
        self._sek210 = None
        self._sek240 = None
        self.discriminator = None
        if domino is not None:
            self.domino = domino
        if prof_tab is not None:
            self.prof_tab = prof_tab
        if nm_0 is not None:
            self.nm_0 = nm_0
        if nm_1 is not None:
            self.nm_1 = nm_1
        if nm_2 is not None:
            self.nm_2 = nm_2
        if nm_3 is not None:
            self.nm_3 = nm_3
        if nm_4 is not None:
            self.nm_4 = nm_4
        if nm_5 is not None:
            self.nm_5 = nm_5
        if nm_6 is not None:
            self.nm_6 = nm_6
        if nm_7 is not None:
            self.nm_7 = nm_7
        if nm_8 is not None:
            self.nm_8 = nm_8
        if nm_9 is not None:
            self.nm_9 = nm_9
        if deputy_minister_finance is not None:
            self.deputy_minister_finance = deputy_minister_finance
        if budget_department_head is not None:
            self.budget_department_head = budget_department_head
        if budget_department_manager is not None:
            self.budget_department_manager = budget_department_manager
        if budget_department_persons is not None:
            self.budget_department_persons = budget_department_persons
        if budget_department_layeman is not None:
            self.budget_department_layeman = budget_department_layeman
        if budget_department_layeman_ph is not None:
            self.budget_department_layeman_ph = budget_department_layeman_ph
        if budget_department_surveyors is not None:
            self.budget_department_surveyors = budget_department_surveyors
        if sek210 is not None:
            self.sek210 = sek210
        if sek240 is not None:
            self.sek240 = sek240

    @property
    def domino(self):
        """Gets the domino of this ProfileRoles.  # noqa: E501


        :return: The domino of this ProfileRoles.  # noqa: E501
        :rtype: DominoCommons
        """
        return self._domino

    @domino.setter
    def domino(self, domino):
        """Sets the domino of this ProfileRoles.


        :param domino: The domino of this ProfileRoles.  # noqa: E501
        :type: DominoCommons
        """

        self._domino = domino

    @property
    def prof_tab(self):
        """Gets the prof_tab of this ProfileRoles.  # noqa: E501

        ProfTab - Záložka  # noqa: E501

        :return: The prof_tab of this ProfileRoles.  # noqa: E501
        :rtype: str
        """
        return self._prof_tab

    @prof_tab.setter
    def prof_tab(self, prof_tab):
        """Sets the prof_tab of this ProfileRoles.

        ProfTab - Záložka  # noqa: E501

        :param prof_tab: The prof_tab of this ProfileRoles.  # noqa: E501
        :type: str
        """

        self._prof_tab = prof_tab

    @property
    def nm_0(self):
        """Gets the nm_0 of this ProfileRoles.  # noqa: E501

        NM_0 - Náměstek  pro odbory č. 0xx (jména)  # noqa: E501

        :return: The nm_0 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_0

    @nm_0.setter
    def nm_0(self, nm_0):
        """Sets the nm_0 of this ProfileRoles.

        NM_0 - Náměstek  pro odbory č. 0xx (jména)  # noqa: E501

        :param nm_0: The nm_0 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_0 = nm_0

    @property
    def nm_1(self):
        """Gets the nm_1 of this ProfileRoles.  # noqa: E501

        NM_1 - Náměstek  pro odbory č. 1xx (jména)  # noqa: E501

        :return: The nm_1 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_1

    @nm_1.setter
    def nm_1(self, nm_1):
        """Sets the nm_1 of this ProfileRoles.

        NM_1 - Náměstek  pro odbory č. 1xx (jména)  # noqa: E501

        :param nm_1: The nm_1 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_1 = nm_1

    @property
    def nm_2(self):
        """Gets the nm_2 of this ProfileRoles.  # noqa: E501

        NM_2 - Náměstek  pro odbory č. 2xx (jména)  # noqa: E501

        :return: The nm_2 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_2

    @nm_2.setter
    def nm_2(self, nm_2):
        """Sets the nm_2 of this ProfileRoles.

        NM_2 - Náměstek  pro odbory č. 2xx (jména)  # noqa: E501

        :param nm_2: The nm_2 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_2 = nm_2

    @property
    def nm_3(self):
        """Gets the nm_3 of this ProfileRoles.  # noqa: E501

        NM_3 - Náměstek  pro odbory č. 3xx (jména)  # noqa: E501

        :return: The nm_3 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_3

    @nm_3.setter
    def nm_3(self, nm_3):
        """Sets the nm_3 of this ProfileRoles.

        NM_3 - Náměstek  pro odbory č. 3xx (jména)  # noqa: E501

        :param nm_3: The nm_3 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_3 = nm_3

    @property
    def nm_4(self):
        """Gets the nm_4 of this ProfileRoles.  # noqa: E501

        NM_4 - Náměstek  pro odbory č. 4xx (jména)  # noqa: E501

        :return: The nm_4 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_4

    @nm_4.setter
    def nm_4(self, nm_4):
        """Sets the nm_4 of this ProfileRoles.

        NM_4 - Náměstek  pro odbory č. 4xx (jména)  # noqa: E501

        :param nm_4: The nm_4 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_4 = nm_4

    @property
    def nm_5(self):
        """Gets the nm_5 of this ProfileRoles.  # noqa: E501

        NM_5 - Náměstek  pro odbory č. 5xx (jména)  # noqa: E501

        :return: The nm_5 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_5

    @nm_5.setter
    def nm_5(self, nm_5):
        """Sets the nm_5 of this ProfileRoles.

        NM_5 - Náměstek  pro odbory č. 5xx (jména)  # noqa: E501

        :param nm_5: The nm_5 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_5 = nm_5

    @property
    def nm_6(self):
        """Gets the nm_6 of this ProfileRoles.  # noqa: E501

        NM_6 - Náměstek  pro odbory č. 6xx (jména)  # noqa: E501

        :return: The nm_6 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_6

    @nm_6.setter
    def nm_6(self, nm_6):
        """Sets the nm_6 of this ProfileRoles.

        NM_6 - Náměstek  pro odbory č. 6xx (jména)  # noqa: E501

        :param nm_6: The nm_6 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_6 = nm_6

    @property
    def nm_7(self):
        """Gets the nm_7 of this ProfileRoles.  # noqa: E501

        NM_7 - Náměstek  pro odbory č. 7xx (jména)  # noqa: E501

        :return: The nm_7 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_7

    @nm_7.setter
    def nm_7(self, nm_7):
        """Sets the nm_7 of this ProfileRoles.

        NM_7 - Náměstek  pro odbory č. 7xx (jména)  # noqa: E501

        :param nm_7: The nm_7 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_7 = nm_7

    @property
    def nm_8(self):
        """Gets the nm_8 of this ProfileRoles.  # noqa: E501

        NM_8 - Náměstek  pro odbory č. 8xx (jména)  # noqa: E501

        :return: The nm_8 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_8

    @nm_8.setter
    def nm_8(self, nm_8):
        """Sets the nm_8 of this ProfileRoles.

        NM_8 - Náměstek  pro odbory č. 8xx (jména)  # noqa: E501

        :param nm_8: The nm_8 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_8 = nm_8

    @property
    def nm_9(self):
        """Gets the nm_9 of this ProfileRoles.  # noqa: E501

        NM_9 - Náměstek  pro odbory č. 9xx (jména)  # noqa: E501

        :return: The nm_9 of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._nm_9

    @nm_9.setter
    def nm_9(self, nm_9):
        """Sets the nm_9 of this ProfileRoles.

        NM_9 - Náměstek  pro odbory č. 9xx (jména)  # noqa: E501

        :param nm_9: The nm_9 of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._nm_9 = nm_9

    @property
    def deputy_minister_finance(self):
        """Gets the deputy_minister_finance of this ProfileRoles.  # noqa: E501

        deputy_minister_finance - Náměstek ŘSFL (jména)  # noqa: E501

        :return: The deputy_minister_finance of this ProfileRoles.  # noqa: E501
        :rtype: str
        """
        return self._deputy_minister_finance

    @deputy_minister_finance.setter
    def deputy_minister_finance(self, deputy_minister_finance):
        """Sets the deputy_minister_finance of this ProfileRoles.

        deputy_minister_finance - Náměstek ŘSFL (jména)  # noqa: E501

        :param deputy_minister_finance: The deputy_minister_finance of this ProfileRoles.  # noqa: E501
        :type: str
        """

        self._deputy_minister_finance = deputy_minister_finance

    @property
    def budget_department_head(self):
        """Gets the budget_department_head of this ProfileRoles.  # noqa: E501

        budget_department_head - Ředitel OR  # noqa: E501

        :return: The budget_department_head of this ProfileRoles.  # noqa: E501
        :rtype: str
        """
        return self._budget_department_head

    @budget_department_head.setter
    def budget_department_head(self, budget_department_head):
        """Sets the budget_department_head of this ProfileRoles.

        budget_department_head - Ředitel OR  # noqa: E501

        :param budget_department_head: The budget_department_head of this ProfileRoles.  # noqa: E501
        :type: str
        """

        self._budget_department_head = budget_department_head

    @property
    def budget_department_manager(self):
        """Gets the budget_department_manager of this ProfileRoles.  # noqa: E501

        budget_department_manager - Autorizace stanoviska OR  # noqa: E501

        :return: The budget_department_manager of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._budget_department_manager

    @budget_department_manager.setter
    def budget_department_manager(self, budget_department_manager):
        """Sets the budget_department_manager of this ProfileRoles.

        budget_department_manager - Autorizace stanoviska OR  # noqa: E501

        :param budget_department_manager: The budget_department_manager of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._budget_department_manager = budget_department_manager

    @property
    def budget_department_persons(self):
        """Gets the budget_department_persons of this ProfileRoles.  # noqa: E501

        budget_department_persons - Odbor rozpočtu - právo přidělování rozpočtáře  # noqa: E501

        :return: The budget_department_persons of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._budget_department_persons

    @budget_department_persons.setter
    def budget_department_persons(self, budget_department_persons):
        """Sets the budget_department_persons of this ProfileRoles.

        budget_department_persons - Odbor rozpočtu - právo přidělování rozpočtáře  # noqa: E501

        :param budget_department_persons: The budget_department_persons of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._budget_department_persons = budget_department_persons

    @property
    def budget_department_layeman(self):
        """Gets the budget_department_layeman of this ProfileRoles.  # noqa: E501

        budget_department_layeman - OVZ - právo přidělování právníka  # noqa: E501

        :return: The budget_department_layeman of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._budget_department_layeman

    @budget_department_layeman.setter
    def budget_department_layeman(self, budget_department_layeman):
        """Sets the budget_department_layeman of this ProfileRoles.

        budget_department_layeman - OVZ - právo přidělování právníka  # noqa: E501

        :param budget_department_layeman: The budget_department_layeman of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._budget_department_layeman = budget_department_layeman

    @property
    def budget_department_layeman_ph(self):
        """Gets the budget_department_layeman_ph of this ProfileRoles.  # noqa: E501

        budget_department_layeman_ph - OVZ - seznam právníků  # noqa: E501

        :return: The budget_department_layeman_ph of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._budget_department_layeman_ph

    @budget_department_layeman_ph.setter
    def budget_department_layeman_ph(self, budget_department_layeman_ph):
        """Sets the budget_department_layeman_ph of this ProfileRoles.

        budget_department_layeman_ph - OVZ - seznam právníků  # noqa: E501

        :param budget_department_layeman_ph: The budget_department_layeman_ph of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._budget_department_layeman_ph = budget_department_layeman_ph

    @property
    def budget_department_surveyors(self):
        """Gets the budget_department_surveyors of this ProfileRoles.  # noqa: E501

        budget_department_surveyors - Odbor rozpočtu - seznam rozpočtářů  # noqa: E501

        :return: The budget_department_surveyors of this ProfileRoles.  # noqa: E501
        :rtype: list[str]
        """
        return self._budget_department_surveyors

    @budget_department_surveyors.setter
    def budget_department_surveyors(self, budget_department_surveyors):
        """Sets the budget_department_surveyors of this ProfileRoles.

        budget_department_surveyors - Odbor rozpočtu - seznam rozpočtářů  # noqa: E501

        :param budget_department_surveyors: The budget_department_surveyors of this ProfileRoles.  # noqa: E501
        :type: list[str]
        """

        self._budget_department_surveyors = budget_department_surveyors

    @property
    def sek210(self):
        """Gets the sek210 of this ProfileRoles.  # noqa: E501

        sek210 - Sekretářka odboru 210  # noqa: E501

        :return: The sek210 of this ProfileRoles.  # noqa: E501
        :rtype: str
        """
        return self._sek210

    @sek210.setter
    def sek210(self, sek210):
        """Sets the sek210 of this ProfileRoles.

        sek210 - Sekretářka odboru 210  # noqa: E501

        :param sek210: The sek210 of this ProfileRoles.  # noqa: E501
        :type: str
        """

        self._sek210 = sek210

    @property
    def sek240(self):
        """Gets the sek240 of this ProfileRoles.  # noqa: E501

        sek240 - Sekretářka odboru 240  # noqa: E501

        :return: The sek240 of this ProfileRoles.  # noqa: E501
        :rtype: str
        """
        return self._sek240

    @sek240.setter
    def sek240(self, sek240):
        """Sets the sek240 of this ProfileRoles.

        sek240 - Sekretářka odboru 240  # noqa: E501

        :param sek240: The sek240 of this ProfileRoles.  # noqa: E501
        :type: str
        """

        self._sek240 = sek240

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ProfileRoles, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProfileRoles):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
